==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/db/storage/wiredtiger/wiredtiger_index_util.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/base/status.h"
#include "mongo/bson/bsonobjbuilder.h"
#include "mongo/db/catalog/validate_results.h"
#include "mongo/db/operation_context.h"

namespace mongo {

class WiredTigerIndexUtil {
    WiredTigerIndexUtil(const WiredTigerIndexUtil&) = delete;
    WiredTigerIndexUtil& operator=(const WiredTigerIndexUtil&) = delete;

private:
    WiredTigerIndexUtil();

public:
    static bool appendCustomStats(OperationContext* opCtx,
                                  BSONObjBuilder* output,
                                  double scale,
                                  const std::string& uri);

    static Status compact(OperationContext* opCtx, const std::string& uri);

    static bool isEmpty(OperationContext* opCtx, const std::string& uri, uint64_t tableId);

    static void validateStructure(OperationContext* opCtx,
                                  const std::string& uri,
                                  IndexValidateResults& results);
};

}  // namespace mongo

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/db/storage/wiredtiger/wiredtiger_index_util.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <cstdint>
#include <string>

#include "mongo/base/status.h"
#include "mongo/bson/bsonobjbuilder.h"
#include "mongo/db/catalog/validate_results.h"
#include "mongo/db/operation_context.h"
#include "mongo/db/storage/wiredtiger/wiredtiger_recovery_unit.h"
#include "mongo/util/interruptible.h"

namespace mongo {

class WiredTigerIndexUtil {
    WiredTigerIndexUtil(const WiredTigerIndexUtil&) = delete;
    WiredTigerIndexUtil& operator=(const WiredTigerIndexUtil&) = delete;

private:
    WiredTigerIndexUtil();

public:
    static bool appendCustomStats(WiredTigerRecoveryUnit&,
                                  BSONObjBuilder* output,
                                  double scale,
                                  const std::string& uri);

    static StatusWith<int64_t> compact(Interruptible&,
                                       WiredTigerRecoveryUnit&,
                                       const std::string& uri,
                                       const CompactOptions& options);

    static bool isEmpty(OperationContext* opCtx, const std::string& uri, uint64_t tableId);

    static void validateStructure(WiredTigerRecoveryUnit&,
                                  const std::string& uri,
                                  IndexValidateResults& results);
};

}  // namespace mongo
